import greenfoot.*;

/**
 * <h2>Class Go</h2>
 * <b>A class used in the demonstration of instantiating a 'Pause' world object.</b><br><br>
 * A simplified example of instantiating a 'Pause' world object follows:<br>
 * <pre>import greenfoot.*;
 * 
 * public class Go extends World
 * {
 *     public Go()
 *     {
 *         super(600, 400, 1);
 *         setPaintOrder(StripedFish.class GreenFish.class, goldFish.class, Turtle.class);
 *         prepare();
 *     }
 *     
 *     private void prepare()
 *     {
 *         // add your objects into the world here
 *     }
 *     
 *     public void act()
 *     {
 *         if(Greenfoot.mouseClicked(null))
 *         {
 *             // the following is the main code to follow to pause the world
 *             Class[] actorClasses={ GreenFish.class, GoldFish.class, StripedFish.class,  Turtle.class, Bones.class, Rock.class };
 *             Class[] paintOrder={ StripedFish.class, GreenFish.class, GoldFish.class, Turtle.class };
 *             Greenfoot.setWorld(new Pause(this, actorClasses, paintOrder));
 *         }
 *     }
 * }<pre>
 */
public class Go extends World
{
    // creates an array of classes to be used in setting the paint order (in that order)
    Class[] paintOrder={ StripedFish.class, GreenFish.class, GoldFish.class, Turtle.class }; // NECCESSARY
    // creates an array of all actor classes that will have objects of that class in the world
    Class[] actorClasses={ GreenFish.class, GoldFish.class, StripedFish.class,  Turtle.class, Bones.class, Rock.class }; // NECCESSARY
    
    /**
     * Creates the world, sets the paint order, and randomly adds a random number of objects into the world.
     */
    public Go()
    {    
        super(600, 400, 1);
        setPaintOrder(paintOrder[0], paintOrder[1], paintOrder[2], paintOrder[3]);
        for(int i=0; i<Greenfoot.getRandomNumber(10)+10; i++)
        {
            int x = Greenfoot.getRandomNumber(getWidth()); // random x
            int y = Greenfoot.getRandomNumber(getHeight()-30); // random y
            int index = Greenfoot.getRandomNumber(actorClasses.length); // random class
            addActor(actorClasses[index], x, y); // creates and adds a new actor of the given class into the world
        }        
    }
    
    /**
     * Creates and adds a new actor of the specified class into the world.
     *
     * @param cls the class from which the new actor is created 
     * @param xLoc the x-coordinate at which to place the object into the world
     * @param yLoc the y-coordinate at which to place the object into the world
     */
    private Actor addActor(Class cls, int xLoc, int yLoc)
    {
        Actor actor=null;
        try { actor=(Actor)cls.newInstance(); } catch(Exception e) { }
        if(actor!=null) addObject(actor, xLoc, yLoc);
        return actor;
    }
    
    /**
     * Checks for a mouse click to trigger changing worlds.
     */
    public void act()
    {
        if(Greenfoot.mouseClicked(null)) Greenfoot.setWorld(new Pause(this, actorClasses, paintOrder));
    }
}